@@ -64,9 +64,9 @@ def download_dataset(dataset_name: str,
             return dirpath
     
     download_is_completed = False
-    num_downloaded_files = 0
-    page = 1
+    page = 0
     while download_is_completed==False:        
+        page += 1
         # Fetch the download info
         res = manager.add_event('get_dataset_download_info', 
                 args=(dataset_name, project_path, version, page), 
@@ -74,7 +74,6 @@ def download_dataset(dataset_name: str,
 
         assert res.get('status_code')==200, res.get('detail')
         downloaded_version = res.get('meta').get('version')
-        num_files = res.get('num_total_results')
 
         dirpath = os.path.join(save_path, dataset_name+'-'+downloaded_version)
 
@@ -105,6 +104,10 @@ def download_dataset(dataset_name: str,
 
         # Download the files
         files = res.get('results')
+        if len(files)==0:
+            download_is_completed = True
+            return dirpath
+
         logger.info(f'Downloading {len(files)} files')
         for file_meta in files:
             url = file_meta['url']
@@ -129,9 +132,5 @@ def download_dataset(dataset_name: str,
                 logger.error(f"Oups, something went wrong while downloading the file {path}.")
             
             logger.info(f'Content saved at {path}')
-            num_downloaded_files += 1
-        page += 1
-        if num_downloaded_files>=num_files:
-            download_is_completed = True
 
     return dirpath
