@@ -39,7 +39,6 @@ def lab_request(path, request_type, form_data=None, query_args=None, body_args=N
         call = requests.post
     try:
         res = call(url, data=body, headers=headers, files=files)
-        logger.debug('LABREQUEST:')
         logger.debug(url)
         logger.debug(res.status_code)
         logger.debug(body)
@@ -55,6 +54,7 @@ def lab_request(path, request_type, form_data=None, query_args=None, body_args=N
             data["status_code"] = res.status_code
             return data
     except:
+        logger.debug(f"Error on call {url}")
         return {"status_code": 400}
 
 
